@@ -6,7 +6,10 @@ from typing import List, Literal, Optional
 
 from python_search.config import PythonSearchConfiguration
 from python_search.events.latest_used_entries import RecentKeys
-from python_search.events.ranking_generated import RankingGenerated, RankingGeneratedWriter
+from python_search.events.ranking_generated import (
+    RankingGenerated,
+    RankingGeneratedWriter,
+)
 from python_search.feature_toggle import FeatureToggle
 from python_search.infrastructure.performance import timeit
 from python_search.search.ranked_entries import RankedEntries
@@ -64,10 +67,14 @@ class Search:
         """Populate the variable used_entries  with the results from redis"""
         result = self._merge_with_latest_used()
 
-        ranknig_generated_event = RankingGenerated(ranking=[i[0] for i in result[0:100]])
+        ranknig_generated_event = RankingGenerated(
+            ranking=[i[0] for i in result[0:100]]
+        )
         self._ranking_generator_writer.write(ranknig_generated_event)
         print(f"Ranking generated UUID {ranknig_generated_event.uuid}")
-        result_str = self._entries_result.build_entries_result(result, ranknig_generated_event.uuid)
+        result_str = self._entries_result.build_entries_result(
+            result, ranknig_generated_event.uuid
+        )
 
         return result_str
 
